﻿* Encoding: UTF-8.
**********************************************************************************************************************************************************************************************
****************************************************** INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS - INEC ***************************************************************
********************************************* DIRECCIÓN DE ESTADÍSTICAS AGROPECUARIAS Y AMBIENTALES - DEAGA *************************************************
*************************** MÓDULO DE INFORMACIÓN ECONÓMICA AMBIENTAL DE LA ENCUESTA ESTRUCTURAL EMPRESARIAL 2017 **************************
*************************************************************** SINTAXIS DE TABULADOS E INDICADORES ************************************************************************
**********************************************************************************************************************************************************************************************

**************************************************************************************
**** A. SINTAXIS DE GENERACIÓN DE TABULADOS DE PUBLICACIÓN.
**************************************************************************************

FILTER OFF.
USE ALL.
SPLIT FILE OFF.

STRING cod_letra (A1).
COMPUTE cod_letra = char.substr(ciiu4_actividad_principal, 1, 1).
FREQUENCIES cod_letra.

VARIABLE LABELS cod_letra "Actividad Económica 2017".
VALUE LABELS cod_letra 'B' "Explotación de Minas y Canteras" 'C' "Industria manufacturera" 'D' "Suministro de electricidad, gas, vapor y aire acondicionado" 
'E' "Distribución de agua, alcantarillado, gestión de desechos y saneamiento" 'F' "Construcción" 'G' "Comercio al por mayor y menor" 'H' "Transporte y Almacenamiento"
'I' "Actividades de alojamiento y servicio de comidas" 'J' "Información y comunicación" 'K' "Actividades financieras y de seguros" 'L' "Actividades inmobiliarias"
'M' "Actividades profesionales, científicas y técnicas" 'N' "Actvidades de servicios administrativos y de apoyo" 'P' "Enseñanza" 
'Q' "Actividades de atención de la salud" 'R' "Artes, entretenimiento y recreación" 'S' "Otras actividades de servicios".

 * RECODE cod_letra ('G' = 1) ('C' = 2) ('F', 'B' = 3) ('H' = 4) ('M' = 5) ('Q' = 6)  ('I' = 7) ('N' = 8) ('P' = 9) ('L' = 10) ('E' = 11) 
('J' = 12) ('D' = 13)  ('S' = 14) ('R' = 15) ('K' = 16) INTO SectorEcon.
 * VARIABLE LABELS SectorEcon "Actividad Económica 2017".
 * VALUE LABELS SectorEcon 1"Comercio" 2"Manufactura" 3"Minas y Construcción" 4"Transporte y Almacenamiento" 5"Actividades profesionales" 
6"Actividades de Salud" 7"Comidas y alojamiento" 8"Actvidades de servicios administrativos y de apoyo" 9"Enseñanza" 10"Actividades inmobiliarias" 
11"Distribución de agua, alcantarillado, gestión de desechos y saneamiento" 12"Información y comunicación" 
13"Suministro de electricidad, gas, vapor y aire acondicionado" 14"Otras actividades de servicios" 15"Artes, entretenimiento y recreación" 
16"Actividades financieras y de seguros".
 * FREQUENCIES SectorEcon.

RECODE cod_tamanio (3,4 = 1) (5 = 2) INTO Tamanio.
VARIABLE LABELS Tamanio "Tamaño de empresa 2017".
VALUE LABELS Tamanio 1'Mediana empresa' 2'Gran empresa'.
FREQUENCIES Tamanio. /* Variable que agrupa a las empresas medianas en un grupo y a las grandes en otro.

COMPUTE NACIONAL = 1. /* Variable que marca a todos los registros de la base de datos, con el fin de desagregar por esta variable cada indicador
/* o tabulado y así obtener el valor nacional del mismo.

WEIGHT BY f_exp.

********************************************************************************************************************************************************************************************.
******************************************************************** GESTIÓN AMBIENTAL ********************************************************************************************.
************************** Tabla 1. Personal dedicado a actividades ambientales a tiempo completo y parcial, por actividad económica *************************************.

CTABLES
  /VLABELS VARIABLES=cod_letra v7002 v7003 v7004 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v7002 [S][SUM, COUNT F40.0] + v7003 [S][SUM, COUNT F40.0] + v7004 [S][SUM, COUNT F40.0]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /TITLES
    TITLE='Tabla 1. Personal dedicado a actividades ambientales a tiempo completo y parcial, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


**************** Tabla 2. Sueldos y salarios del personal dedicado a actividades ambientales y sueldos ambientales medios, por actividad económica ****************.

WEIGHT OFF.

COMPUTE Sueldos_AMB = sum.1(v7005, v7006).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra Sueldos_AMB v7002 DISPLAY=LABEL
  /TABLE cod_letra [C] BY Sueldos_AMB [S][SUM] + v7002 [S][SUM, COUNT F40.0]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /TITLES
    TITLE='Tabla 2. Sueldos y salarios del personal dedicado a actividades ambientales y sueldos ambientales medios, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.

DELETE VARIABLES Sueldos_AMB.


********************* Tabla 3. Gastos corrientes y gasto corriente medio por empresa en bienes y servicios ambientales, por actividad económica *********************.

CTABLES
  /VLABELS VARIABLES=cod_letra v74 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v74 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=v74 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Tabla 3. Gastos corrientes y gasto corriente medio por empresa en bienes y servicios ambientales, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


****************************************************************** BIENES Y SERVICIOS AMBIENTALES  *************************************************************************.
********************** Tabla 4. Gastos corrientes y gasto corriente medio por empresa en bienes y servicios ambientales, por actividad económica *********************.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE FIL_v8100 = (v8100 > 0).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra v8100 FIL_v8100 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v8100 [S][SUM, COUNT F40.0] + FIL_v8100 [COUNT]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=FIL_v8100 [1] EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 4. Gastos corrientes y gasto corriente medio por empresa en bienes y servicios ambientales, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


********************* Tabla 5. Producción ambiental y producción media por empresa en bienes y servicios ambientales, por actividad económica *********************.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE FIL_v8098 = (v8098 > 0).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra v8098 FIL_v8098 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v8098 [S][SUM, COUNT F40.0] + FIL_v8098 [COUNT]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=FIL_v8098 [1] EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 5. Producción ambiental y producción media por empresa en bienes y servicios ambientales, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


********************** Tabla 6. Inversión ambiental e inversión media por empresa en bienes y servicios ambientales, por actividad económica **********************.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE FIL_v8099 = (v8099 > 0).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra v8099 FIL_v8099 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v8099 [S][SUM, COUNT F40.0] + FIL_v8099 [COUNT]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=FIL_v8099 [1] EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 6. Inversión ambiental e inversión media por empresa en bienes y servicios ambientales, por actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


******************************** Tabla 7. Gastos corrientes en temas de protección ambiental, por objetivos ambientales ********************************.

CTABLES
  /VLABELS VARIABLES=v8007 v8013 v8019 v8025 v8031 v8037 v8043 v8049 v8055 
    DISPLAY=LABEL
  /TABLE v8007 [S][SUM] + v8013 [S][SUM] + v8019 [S][SUM] + v8025 [S][SUM] + v8031 [S][SUM] + v8037 [S][SUM] + 
    v8043 [S][SUM] + v8049 [S][SUM] + v8055 [SUM]
  /TITLES
    TITLE='Tabla 7. Gastos corrientes en temas de protección ambiental, por objetivos ambientales'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************************** Tabla 8. Gastos Corrientes en temas de Gestión de Recursos Naturales, por objetivos ambientales **************************.

CTABLES
  /VLABELS VARIABLES=v8061 v8067 v8073 v8079 v8085 v8091 v8097 
    DISPLAY=LABEL
  /TABLE v8061 [S][SUM] + v8067 [S][SUM] + v8073 [S][SUM] + v8079 [S][SUM] + v8085 [S][SUM] + v8091 [S][SUM] + v8097 [S][SUM]
  /TITLES
    TITLE='Tabla 8. Gastos Corrientes en temas de Gestión de Recursos Naturales, por objetivos ambientales'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


***************************************************************** ENERGÍA, COMBUSTIBLES Y LUBRICANTES *******************************************************************************.
*********** Tabla 9. Energía de red pública, cantidad, valor pagado, consumo medio, valor pagado medio por empresa y tarifa media, por tipo de actividad económica ***********.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE FIL_v9001 = (v9001 > 0).
EXECUTE.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra FIL_v9001 v9001 v9002 NACIONAL DISPLAY=LABEL
  /TABLE cod_letra [C] BY FIL_v9001 [C] > (v9001 [S][SUM] + v9002 [S][SUM, COUNT F40.0]) + NACIONAL [COUNT F40.0]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=FIL_v9001 NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 9. Energía de red pública, cantidad, valor pagado, consumo medio, valor pagado medio por empresa y tarifa media, por tipo de actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************ Tabla 10. Energía eléctrica alternativa generada, por tipo de actividad económica y según uso principal de la energía producida y consumida ************.

CTABLES
  /VLABELS VARIABLES=cod_letra v9047 v9048 v9049 v9010 v9011 v9018 v9019 v9026 v9027 v9034 v9035 v9042 v9043 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v9047 [S][SUM] + v9048 [S][SUM] + v9049 [S][SUM] + v9010 [SUM, ROWPCT.SUM PCT40.1] > v9011 [C]
    + v9018 [SUM, ROWPCT.SUM PCT40.1] > v9019 [C] + v9026 [SUM, ROWPCT.SUM PCT40.1] > v9027 [C]
    + v9034 [SUM, ROWPCT.SUM PCT40.1] > v9035 [C] + v9042 [SUM, ROWPCT.SUM PCT40.1] > v9043 [C]
  /CATEGORIES VARIABLES=cod_letra v9011 v9019 v9027 v9035 v9043 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /TITLES
    TITLE='Tabla 10. Energía eléctrica alternativa generada, por tipo de actividad económica y según uso principal de la energía producida y consumida'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************** Tabla 11. Volúmenes de Combustibles y Lubricantes líquidos usados en las empresas, por tipo de combustible y según uso principal del mismo **************.

CTABLES
  /VLABELS VARIABLES=v9053 v9057 v9061 v9065 v9077 v9081 v9097 v9105 DISPLAY=LABEL
  /TABLE v9053 [S][SUM] + v9057 [S][SUM] + v9061 [S][SUM] + v9065 [S][SUM] + v9077 [S][SUM] + v9081 [S][SUM] + v9097 [S][SUM] + v9105 [S][SUM]
  /TITLES
    TITLE='Tabla 11a. Valor pagado por los combustibles líquidos'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.

CTABLES
  /VLABELS VARIABLES=v9052 v9054 v9056 v9058 v9060 v9062 v9064 v9066 v9076 v9078 v9080 v9082 v9096 v9098 v9104 v9106 DISPLAY=LABEL
  /TABLE BY v9052 [S][SUM, ROWPCT.SUM PCT40.1] > v9054 [C] + v9056 [S][SUM, ROWPCT.SUM PCT40.1] > v9058 [C] 
  + v9060 [S][SUM, ROWPCT.SUM PCT40.1] > v9062 [C] + v9064 [S][SUM, ROWPCT.SUM PCT40.1] > v9066 [C]
  + v9076 [S][SUM, ROWPCT.SUM PCT40.1] > v9078 [C] + v9080 [S][SUM, ROWPCT.SUM PCT40.1] > v9082 [C]
  + v9096 [S][SUM, ROWPCT.SUM PCT40.1] > v9098 [C] + v9104 [S][SUM, ROWPCT.SUM PCT40.1] > v9106 [C]
  /CATEGORIES VARIABLES=v9054 v9058 v9062 v9066 v9078 v9082 v9098 v9106 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE  
  /TITLES
    TITLE='Tabla 11b. Volúmenes de Combustibles y Lubricantes líquidos usados en las empresas, por tipo de combustible y según uso principal del mismo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


**************** Tabla 12. Masas de Combustibles y Lubricantes sólidos usados en las empresas, por tipo de combustible y según uso principal del mismo ****************.

CTABLES
  /VLABELS VARIABLES=v9069 v9085 v9101 DISPLAY=LABEL
  /TABLE v9069 [SUM] + v9085 [SUM] + v9101 [SUM]
  /TITLES
    TITLE='Tabla 12a. Valor pagado por los combustibles sólidos'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.

FILTER OFF.
USE ALL.
WEIGHT OFF.

IF (v9070 = 0) v9070 = 6.
IF (v9102 = 0) v9102 = 6.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=v9068 v9070 v9084 v9086 v9100 v9102 DISPLAY=LABEL
  /TABLE BY v9068 [S][SUM, ROWPCT.SUM PCT40.1] > v9070 [C] + v9084 [S][SUM, ROWPCT.SUM PCT40.1] > v9086 [C] 
  + v9100 [S][SUM, ROWPCT.SUM PCT40.1] > v9102 [C]
  /CATEGORIES VARIABLES=v9070 v9086 v9102 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE 
  /TITLES
    TITLE='Tabla 12b. Masas de Combustibles y Lubricantes sólidos usados en las empresas, por tipo de combustible y según uso principal del mismo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************************************************************************ AGUA Y MANEJO DE AGUAS RESIDUALES ************************************************************************.
*********** Tabla 13. Agua de red pública, cantidad, valor pagado, consumo medio, valor pagado medio por empresa y tarifa media, por tipo de actividad económica ***********.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE FIL_v10000 = (v10000 > 0).
EXECUTE.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra FIL_v10000 v10000 v10001 NACIONAL DISPLAY=LABEL
  /TABLE cod_letra [C] BY FIL_v10000 [C] > (v10000 [S][SUM] + v10001 [S][SUM, COUNT F40.0]) + NACIONAL [COUNT F40.0]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=FIL_v10000 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 13. Agua de red pública, cantidad, valor pagado, consumo medio, valor pagado medio por empresa y tarifa media, por tipo de actividad económica'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************* Tabla 14. Empresas que cuentan con fuentes naturales de captación de agua, por tipo de actividad económica y según fuente de captación *************.

STRING cod_letra2 (A1).
COMPUTE cod_letra2 = cod_letra.
IF (ANY(cod_letra, 'J', 'K', 'M', 'N', 'Q', 'R', 'S')) cod_letra2 = 'X'.
VALUE LABELS cod_letra2 'B' "Explotación de Minas y Canteras" 'C' "Industria manufacturera" 'D' "Suministro de electricidad, gas, vapor y aire acondicionado" 
'E' "Distribución de agua, alcantarillado, gestión de desechos y saneamiento" 'F' "Construcción" 'G' "Comercio al por mayor y menor" 'H' "Transporte y Almacenamiento"
'I' "Actividades de alojamiento y servicio de comidas" 'L' "Actividades inmobiliarias" 'P' "Enseñanza" 'X' "Otras actividades".

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra2 v10i4 v10009 v10017 v10025 DISPLAY=LABEL
  /TABLE NACIONAL [C] + cod_letra2 [C] BY v10i4 [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + v10009 [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
  + v10017 [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + v10025 [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL v10i4 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=cod_letra2 v10009 v10017 v10025 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
    TITLE='Tabla 14. Empresas que cuentan con fuentes naturales de captación de agua, por tipo de actividad económica y según fuente de captación'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


******* Tabla 15. Empresas que cuentan con autorización de SENAGUA para uso de aguas captadas, por actividad económica y según fuente de captación *******.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE Tiene_Seg_SENAGUA = MIN(v10010, v10018, v10026).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra2 v10i4 Tiene_Seg_SENAGUA v10009 v10010 v10017 v10018 v10025 v10026 DISPLAY=LABEL
  /TABLE NACIONAL [C] + cod_letra2 [C] BY v10i4 [C][COUNT F40.0] + Tiene_Seg_SENAGUA [C][COUNT 
    F40.0] + v10009 [C] > v10010 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + v10017 [C] > v10018 [C][COUNT 
    F40.0, ROWPCT.COUNT PCT40.1] + v10025 [C] > v10026 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10i4 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=Tiene_Seg_SENAGUA [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=cod_letra2 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10009 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10017 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10025 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10010 v10018 v10026 [1, 2, OTHERNM] EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE 
  /TITLES
    TITLE='Tabla 15. Empresas que cuentan con autorización de SENAGUA para uso de aguas captadas, por actividad económica y según fuente de captación'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************ Tabla 16. Empresas que cuentan con registro interno de uso de aguas captadas, por actividad económica y según fuente de captación ************.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE Tiene_Reg_H2O_Capt = MIN(v10011, v10019, v10027).

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra2 v10i4 Tiene_Reg_H2O_Capt v10009 v10011 v10017 v10019 v10025 v10027 DISPLAY=LABEL
  /TABLE NACIONAL [C] + cod_letra2 [C] BY v10i4 [C][COUNT F40.0] + Tiene_Reg_H2O_Capt [C][COUNT 
    F40.0] + v10009 [C] > v10011 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + v10017 [C] > v10019 [C][COUNT 
    F40.0, ROWPCT.COUNT PCT40.1] + v10025 [C] > v10027 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10i4 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=Tiene_Reg_H2O_Capt [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=cod_letra2 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10009 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10017 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10025 [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=v10011 v10019 v10027 [1, 2, OTHERNM] EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE 
  /TITLES
    TITLE='Tabla 16. Empresas que cuentan con registro interno de uso de aguas captadas, por actividad económica y según fuente de captación'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


************ Tabla 17. Volúmenes de aguas residuales generadas en el proceso productivo, por actividad económica y según tipo de tratamiento dado ************.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

IF (cod_letra = 'M' & Missing(v10ii2)) v10ii2 = 2.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=cod_letra v10ii2 v10ii3 v10038 v10ii5 DISPLAY=LABEL
  /TABLE cod_letra [C] BY v10ii2 [COUNT F40.0, ROWPCT.COUNT PCT40.1] + v10ii3 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  + v10038 [S][SUM, ROWPCT.SUM PCT40.1] > v10ii5 [C]
  /CATEGORIES VARIABLES=cod_letra v10ii5 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=v10ii2 v10ii3 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=BEFORE
  /TITLES
    TITLE='Tabla 17. Volúmenes de aguas residuales generadas en el proceso productivo, por actividad económica y según tipo de tratamiento dado'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2017'.


*************************************************************************** RESIDUOS **************************************************************************************************.
************************************* Tabla 18. Empresas que generaron residuos no peligrosos, por tipo de residuo    *********************************************************.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE Gen_RES_NO_PEL = MIN(v10065, v10084, v10103, v10122, v10141, v10160, v10179, v10198, v10217, v10236, v10255, v10274, v10293, v10312).
VARIABLE LABELS Gen_RES_NO_PEL "Genera residuos no peligrosos".
VALUE LABELS Gen_RES_NO_PEL 1"Sí" 2"No".

WEIGHT BY f_exp.

FREQUENCIES Gen_RES_NO_PEL.

CTABLES
  /VLABELS VARIABLES=v10065 v10084 v10103 v10122 v10141 v10160 v10179 v10198 v10217 v10236 v10255 v10274 v10293 v10312 DISPLAY=LABEL
  /TABLE v10065 [COUNT F40.0] + v10084 [COUNT F40.0] + v10103 [COUNT F40.0] + v10122 [COUNT F40.0] + v10141 [COUNT F40.0] 
   + v10160 [COUNT F40.0] + v10179 [COUNT F40.0] + v10198 [COUNT F40.0] + v10217 [COUNT F40.0] + v10236 [COUNT F40.0] 
   + v10255 [COUNT F40.0] + v10274 [COUNT F40.0] + v10293 [COUNT F40.0] + v10312 [COUNT F40.0]
  /SLABELS VISIBLE=NO /CLABELS ROWLABELS=OPPOSITE
  /CATEGORIES VARIABLES=v10065 v10084 v10103 v10122 v10141 v10160 v10179 v10198 v10217 v10236 v10255 v10274 v10293
    v10312 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 18a. Empresas que generaron residuos no peligrosos, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.

WEIGHT OFF.

* Transformación de Kilogramos a toneladas.
IF (v10067 = 1) v10068_S = v10068 / 1000.
IF (v10086 = 1) v10087_S = v10087 / 1000.
IF (v10105 = 1) v10106_S = v10106 / 1000.
IF (v10124 = 1) v10125_S = v10125 / 1000.
IF (v10143 = 1) v10144_S = v10144 / 1000.
IF (v10162 = 1) v10163_S = v10163 / 1000.
IF (v10181 = 1) v10182_S = v10182 / 1000.
IF (v10200 = 1) v10201_S = v10201 / 1000.
IF (v10219 = 1) v10220_S = v10220 / 1000.
IF (v10238 = 1) v10239_S = v10239 / 1000.
IF (v10257 = 1) v10258_S = v10258 / 1000.
IF (v10276 = 1) v10277_S = v10277 / 1000.
IF (v10295 = 1) v10296_S = v10296 / 1000.
IF (v10314 = 1) v10315_S = v10315 / 1000.
EXECUTE.

* Transformación de toneladas a toneladas.
IF (v10067 = 2) v10068_S = v10068.
IF (v10086 = 2) v10087_S = v10087.
IF (v10105 = 2) v10106_S = v10106.
IF (v10124 = 2) v10125_S = v10125.
IF (v10143 = 2) v10144_S = v10144.
IF (v10162 = 2) v10163_S = v10163.
IF (v10181 = 2) v10182_S = v10182.
IF (v10200 = 2) v10201_S = v10201.
IF (v10219 = 2) v10220_S = v10220.
IF (v10238 = 2) v10239_S = v10239.
IF (v10257 = 2) v10258_S = v10258.
IF (v10276 = 2) v10277_S = v10277.
IF (v10295 = 2) v10296_S = v10296.
IF (v10314 = 2) v10315_S = v10315.
EXECUTE.

*Nombre de las variables.
VARIABLE LABELS v10068_S "Chatarra Liviana".
VARIABLE LABELS v10087_S "Papel y cartón".
VARIABLE LABELS v10106_S "Orgánicos".
VARIABLE LABELS v10125_S "Plástico".
VARIABLE LABELS v10144_S "Caucho".
VARIABLE LABELS v10163_S "Vidrio".
VARIABLE LABELS v10182_S "Madera".
VARIABLE LABELS v10201_S "Textiles".
VARIABLE LABELS v10220_S "Escombros de construcción".
VARIABLE LABELS v10239_S "Chatarra pesada".
VARIABLE LABELS v10258_S "Muebles y enseres viejos".
VARIABLE LABELS v10277_S "Metal (estructuras metálicas perfiles paneles en mal estado)".
VARIABLE LABELS v10296_S "Vehículos fuera de uso".
VARIABLE LABELS v10315_S "Colchones viejos".

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=v10068_S v10087_S v10106_S v10125_S v10144_S v10163_S v10182_S v10201_S 
    v10220_S v10239_S v10258_S v10277_S v10296_S v10315_S DISPLAY=LABEL
  /TABLE v10068_S [S][SUM, VALIDN F40.0] + v10087_S [S][SUM, VALIDN F40.0] + v10106_S [SUM, VALIDN F40.0] 
    + v10125_S [SUM, VALIDN F40.0] + v10144_S [SUM, VALIDN F40.0] + v10163_S [SUM, VALIDN F40.0] 
    + v10182_S [SUM, VALIDN F40.0] + v10201_S [SUM, VALIDN F40.0] + v10220_S [SUM, VALIDN F40.0] 
    + v10239_S [SUM, VALIDN F40.0] + v10258_S [SUM, VALIDN F40.0] + v10277_S [SUM, VALIDN F40.0] 
    + v10296_S [S][SUM, VALIDN F40.0] + v10315_S [SUM, VALIDN F40.0]
  /TITLES
    TITLE='Tabla 18b. Cantidades de residuos no peligrosos generados (ton) y empresas que conocen dichas cantidades, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.


*******************************************  Tabla 19. Empresas que generaron residuos especiales,por tipo de residuo *********************************************************.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE Gen_RES_ESP = MIN(v10331, v10350, v10369, v10388, v10407, v10426, v10445, v10464).
VARIABLE LABELS Gen_RES_ESP "Genera residuos especiales".
VALUE LABELS Gen_RES_ESP 1"Sí" 2"No".

WEIGHT BY f_exp.

FREQUENCIES Gen_RES_ESP.

CTABLES
  /VLABELS VARIABLES=v10331 v10350 v10369 v10388 v10407 v10426 v10445 v10464 DISPLAY=LABEL
  /TABLE v10331 [COUNT F40.0] + v10350 [COUNT F40.0] + v10369 [COUNT F40.0] + v10388 [COUNT F40.0] + v10407 [COUNT F40.0] 
   + v10426 [COUNT F40.0] + v10445 [COUNT F40.0] + v10464 [COUNT F40.0]
  /SLABELS VISIBLE=NO /CLABELS ROWLABELS=OPPOSITE
  /CATEGORIES VARIABLES=v10331 v10350 v10369 v10388 v10407 v10426 v10445 v10464 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 19a. Empresas que generaron residuos especiales, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.

WEIGHT OFF.

* Transformación de Kilogramos a toneladas.
IF (v10333 = 1) v10334_S = v10334 / 1000.
IF (v10352 = 1) v10353_S = v10353 / 1000.
IF (v10371 = 1) v10372_S = v10372 / 1000.
IF (v10390 = 1) v10391_S = v10391 / 1000.
IF (v10409 = 1) v10410_S = v10410 / 1000.
IF (v10428 = 1) v10429_S = v10429 / 1000.
IF (v10447 = 1) v10448_S = v10448 / 1000.
IF (v10466 = 1) v10467_S = v10467 / 1000.
EXECUTE.

* Transformación de toneladas a toneladas.
IF (v10333 = 2) v10334_S = v10334.
IF (v10352 = 2) v10353_S = v10353.
IF (v10371 = 2) v10372_S = v10372.
IF (v10390 = 2) v10391_S = v10391.
IF (v10409 = 2) v10410_S = v10410.
IF (v10428 = 2) v10429_S = v10429.
IF (v10447 = 2) v10448_S = v10448.
IF (v10466 = 2) v10467_S = v10467.
EXECUTE.

*Nombre de las variables.
VARIABLE LABELS v10334_S"Neumáticos usados o parte de los mismos".
VARIABLE LABELS v10353_S"Aceites vegetales usados generados en procesos de fritura de alimentos".
VARIABLE LABELS v10372_S"Equipos eléctricos y electrónicos en desuso que han sido desensamblados, separados sus componentes o elementos constitutivos".
VARIABLE LABELS v10391_S"Envases vacíos de agroquímicos con triple lavado".
VARIABLE LABELS v10410_S"Envases/contenedores vacíos de químicos tóxicos luego del tratamiento".
VARIABLE LABELS v10429_S"Plásticos de invernadero".
VARIABLE LABELS v10448_S"Fundas biflex, corbatines y protectores usados".
VARIABLE LABELS v10467_S"Escorías de acería cuyos componentes tóxicos se encuentren bajo los valores establecidos en las normas técnicas correspondientes".

WEIGHT BY f_exp.

* Suma en toneladas.
CTABLES
  /VLABELS VARIABLES=v10334_S v10353_S v10372_S v10391_S v10410_S v10429_S v10448_S v10467_S DISPLAY=LABEL
  /TABLE v10334_S [S][SUM, VALIDN F40.0] + v10353_S [S][SUM, VALIDN F40.0] + v10372_S [S][SUM, VALIDN F40.0] + v10391_S [S][SUM, VALIDN F40.0] + v10410_S 
    [S][SUM, VALIDN F40.0] + v10429_S [S][SUM, VALIDN F40.0] + v10448_S [S][SUM, VALIDN F40.0] + v10467_S [S][SUM, VALIDN F40.0]
  /TITLES
    TITLE='Tabla 19b. Cantidades de residuos no peligrosos generados (ton) y empresas que conocen dichas cantidades, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.


******************************   Tabla 20. Empresas que generaron residuos peligrosos líquidos, por tipo de residuo  ***********************************************************.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE Gen_RES_PEL_LIQ = MIN(v10483, v10502, v10521, v10540, v10559, v10578).
VARIABLE LABELS Gen_RES_PEL_LIQ "Genera residuos peligrosos líquidos".
VALUE LABELS Gen_RES_PEL_LIQ 1"Sí" 2"No".

WEIGHT BY f_exp.

FREQUENCIES Gen_RES_PEL_LIQ.

CTABLES
  /VLABELS VARIABLES=v10483 v10502 v10521 v10540 v10559 v10578 DISPLAY=LABEL
  /TABLE v10483 [COUNT F40.0] + v10502 [COUNT F40.0] + v10521 [COUNT F40.0] + v10540 [COUNT F40.0] + v10559 [COUNT F40.0] 
   + v10578 [COUNT F40.0]
  /SLABELS VISIBLE=NO /CLABELS ROWLABELS=OPPOSITE
  /CATEGORIES VARIABLES=v10483 v10502 v10521 v10540 v10559 v10578 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 20a. Empresas que generaron residuos peligrosos líquidos, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.

WEIGHT OFF.

* Transformación de litros a litros.
IF (v10485 = 1) v10486_S = v10486.
IF (v10504 = 1) v10505_S = v10505.
IF (v10523 = 1) v10524_S = v10524.
IF (v10542 = 1) v10543_S = v10543.
IF (v10561 = 1) v10562_S = v10562.
IF (v10580 = 1) v10581_S = v10581.
EXECUTE.

* Transformación de galones a litros.
IF (v10485 = 2) v10486_S = v10486 * 3.785.
IF (v10504 = 2) v10505_S = v10505 * 3.785.
IF (v10523 = 2) v10524_S = v10524 * 3.785.
IF (v10542 = 2) v10543_S = v10543 * 3.785.
IF (v10561 = 2) v10562_S = v10562 * 3.785.
IF (v10580 = 2) v10581_S = v10581 * 3.785.
EXECUTE.

*Nombre de las variables.
VARIABLE LABELS v10486_S"Solventes usados".
VARIABLE LABELS v10505_S"Ácidos, alcalinos o sales".
VARIABLE LABELS v10524_S"Aceites usados".
VARIABLE LABELS v10543_S"Fluido refrigerante".
VARIABLE LABELS v10562_S"Aditivos cementicios".
VARIABLE LABELS v10581_S"Depósitos y residuos químicos".

WEIGHT BY f_exp.

* Suma en Galones.
CTABLES
  /VLABELS VARIABLES=v10486_S v10505_S v10524_S v10543_S v10562_S v10581_S DISPLAY=LABEL
  /TABLE v10486_S [S][SUM, VALIDN F40.0] + v10505_S [S][SUM, VALIDN F40.0] + v10524_S [S][SUM, VALIDN F40.0] 
  + v10543_S [S][SUM, VALIDN F40.0] + v10562_S [S][SUM, VALIDN F40.0] + v10581_S [S][SUM, VALIDN F40.0]
  /TITLES
    TITLE='Tabla 20b. Cantidades de residuos peligrosos líquidos (litros) y empresas que conocen dichas cantidades, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.


**********************************  Tabla 21. Empresas que generaron residuos peligrosos sólidos,por tipo de residuo  ********************************************************.

WEIGHT OFF.

COMPUTE Gen_RES_PEL_SOL = MIN(v10597, v10616, v10635, v10654, v10673, v10692, v10711, v10730, v10749, v10768, v10787, v10806, v10825, v10844, v10863, v10882).
VARIABLE LABELS Gen_RES_PEL_SOL "Genera residuos peligrosos sólidos".
VALUE LABELS Gen_RES_PEL_SOL 1"Sí" 2"No".

WEIGHT BY f_exp.

FREQUENCIES Gen_RES_PEL_SOL.

CTABLES
  /VLABELS VARIABLES=v10597 v10616 v10635 v10654 v10673 v10692 v10711 v10730 v10749 v10768 v10787 v10806 v10825 v10844 v10863 v10882 DISPLAY=LABEL
  /TABLE v10597 [COUNT F40.0] + v10616 [COUNT F40.0] + v10635 [COUNT F40.0] + v10654 [COUNT F40.0] + v10673 [COUNT F40.0] + v10692 [COUNT F40.0]
  + v10711 [COUNT F40.0] + v10730 [COUNT F40.0] + v10749 [COUNT F40.0] + v10768 [COUNT F40.0] + v10787 [COUNT F40.0] + v10806 [COUNT F40.0]
  + v10825 [COUNT F40.0] + v10844 [COUNT F40.0] + v10863 [COUNT F40.0] + v10882 [COUNT F40.0]
  /SLABELS VISIBLE=NO /CLABELS ROWLABELS=OPPOSITE
  /CATEGORIES VARIABLES=v10597 v10616 v10635 v10654 v10673 v10692 v10711 v10730 v10749 v10768 v10787 v10806 v10825 v10844 v10863 v10882
    ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Tabla 21a. Empresas que generaron residuos peligrosos sólidos, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.

WEIGHT OFF.

* Transformación de Kilogramos a toneladas.
IF (v10599 = 1) v10600_S = v10600 / 1000.
IF (v10618 = 1) v10619_S = v10619 / 1000.
IF (v10637 = 1) v10638_S = v10638 / 1000.
IF (v10656 = 1) v10657_S = v10657 / 1000.
IF (v10675 = 1) v10676_S = v10676 / 1000.
IF (v10694 = 1) v10695_S = v10695 / 1000.
IF (v10713 = 1) v10714_S = v10714 / 1000.
IF (v10732 = 1) v10733_S = v10733 / 1000.
IF (v10751 = 1) v10752_S = v10752 / 1000.
IF (v10770 = 1) v10771_S = v10771 / 1000.
IF (v10789 = 1) v10790_S = v10790 / 1000.
IF (v10808 = 1) v10809_S = v10809 / 1000.
IF (v10827 = 1) v10828_S = v10828 / 1000.
IF (v10846 = 1) v10847_S = v10847 / 1000.
IF (v10865 = 1) v10866_S = v10866 / 1000.
IF (v10884 = 1) v10885_S = v10885 / 1000.
EXECUTE.

* Transformación de toneladas a toneladas.
IF (v10599 = 2) v10600_S = v10600.
IF (v10618 = 2) v10619_S = v10619.
IF (v10637 = 2) v10638_S = v10638.
IF (v10656 = 2) v10657_S = v10657.
IF (v10675 = 2) v10676_S = v10676.
IF (v10694 = 2) v10695_S = v10695.
IF (v10713 = 2) v10714_S = v10714.
IF (v10732 = 2) v10733_S = v10733.
IF (v10751 = 2) v10752_S = v10752.
IF (v10770 = 2) v10771_S = v10771.
IF (v10789 = 2) v10790_S = v10790.
IF (v10808 = 2) v10809_S = v10809.
IF (v10827 = 2) v10828_S = v10828.
IF (v10846 = 2) v10847_S = v10847.
IF (v10865 = 2) v10866_S = v10866.
IF (v10884 = 2) v10885_S = v10885.
EXECUTE.

*Nombre de las variables.
VARIABLE LABELS v10600_S"Medicamentos no utilizados".
VARIABLE LABELS v10619_S"Sanitarios biológicos".
VARIABLE LABELS v10638_S"Trapos y/o brochas contaminantes".
VARIABLE LABELS v10657_S"Materiales y recipientes de laboratorio (no biológico)".
VARIABLE LABELS v10676_S"Material absorbente trapos y/o wypes contaminados con hidrocarburos".
VARIABLE LABELS v10695_S"Correas transportadoras".
VARIABLE LABELS v10714_S"Baterías de vehículos".
VARIABLE LABELS v10733_S"Tóner".
VARIABLE LABELS v10752_S"Pilas y acumuladores".
VARIABLE LABELS v10771_S"Luminarias, lámparas, tubos, fluorescentes, focos ahorradores".
VARIABLE LABELS v10790_S"Lodos generados en el proceso productivo".
VARIABLE LABELS v10809_S"Suelo y lodos de drenaje contaminados".
VARIABLE LABELS v10828_S"Asfalto".
VARIABLE LABELS v10847_S"Tierras contaminadas".
VARIABLE LABELS v10866_S"Depósito de combustibles".
VARIABLE LABELS v10885_S"Estiércol producido en los mataderos".

WEIGHT BY f_exp.

* Suma en toneladas.
CTABLES
  /VLABELS VARIABLES=v10600_S v10619_S v10638_S v10657_S v10676_S v10695_S v10714_S v10733_S v10752_S v10771_S v10790_S v10809_S v10828_S
   v10847_S v10866_S v10885_S DISPLAY=LABEL
  /TABLE v10600_S [S][SUM, VALIDN F40.0] + v10619_S [S][SUM, VALIDN F40.0] + v10638_S [S][SUM, VALIDN F40.0] + v10657_S [S][SUM, VALIDN F40.0] 
           + v10676_S [S][SUM, VALIDN F40.0] + v10695_S [S][SUM, VALIDN F40.0] + v10714_S [S][SUM, VALIDN F40.0] + v10733_S [S][SUM, VALIDN F40.0] 
           + v10752_S [S][SUM, VALIDN F40.0] + v10771_S [S][SUM, VALIDN F40.0] + v10790_S [S][SUM, VALIDN F40.0] + v10809_S [S][SUM, VALIDN F40.0] 
           + v10828_S [S][SUM, VALIDN F40.0] + v10847_S [S][SUM, VALIDN F40.0] + v10866_S [S][SUM, VALIDN F40.0]+ v10885_S [S][SUM, VALIDN F40.0]
  /TITLES
    TITLE='Tabla 21b. Cantidades de residuos peligrosos sólidos (ton) y empresas que conocen dichas cantidades, por tipo de residuo'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Industrial 2018'.


******************************************************************  FIN SINTAXIS DE TABULADOS **************************************************************************.

DELETE VARIABLES FIL_v8100 FIL_v8098 FIL_v8099 FIL_v9001 FIL_v10000 cod_letra2 Tiene_Seg_SENAGUA Tiene_Reg_H2O_Capt Gen_RES_NO_PEL
v10068_S v10087_S v10106_S v10125_S v10144_S v10163_S v10182_S v10201_S v10220_S v10239_S v10258_S v10277_S v10296_S v10315_S Gen_RES_ESP
v10334_S v10353_S v10372_S v10391_S v10410_S v10429_S v10448_S v10467_S Gen_RES_PEL_LIQ
v10486_S v10505_S v10524_S v10543_S v10562_S v10581_S Gen_RES_PEL_SOL
v10600_S v10619_S v10638_S v10657_S v10676_S v10695_S v10714_S v10733_S v10752_S v10771_S v10790_S v10809_S v10828_S v10847_S v10866_S v10885_S.

************************************************************************************************************************
**** B. SINTAXIS DE INDICADORES, MÓDULO AMBIENTAL DE LA ENCUESTA ESTRUCTURAL 2017.
***********************************************************************************************************************
***********************************************************************************************************************************************************************************
***********************************************************************************************************************************************************************************

* CÁLCULO DE INDICADORES.

* Indicador 1. Proporción de empresas con certificación ISO 14001.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE PISO = 0.
IF (v75 = 1) PISO = 1.
VARIABLE LABELS PISO "Empresas con certificación ISO 14001, AÑO 2017".
VALUE LABELS PISO 0'No' 1'Sí'.
FREQUENCIES PISO.

* Tabulado a publicar.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra Tamanio PISO DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + cod_letra [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + Tamanio [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] BY PISO [C]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=cod_letra EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=Tamanio EMPTY=INCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=PISO [1, 0, OTHERNM] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Indicador 1. Proporción de empresas con certificación ISO 14001 en el año 2017 (%)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

**********************************************************************************************

* Indicador 2. Proporción de empresas que realizaron inversión ambiental.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE PEIA = 0.
IF (v8099 > 0) PEIA = 1.
VARIABLE LABELS PEIA "Empresas que realizaron inversión ambiental 2017".
VALUE LABELS PEIA 0'No' 1'Sí'.
FREQUENCIES PEIA.

* Tabulado a publicar.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra Tamanio PEIA DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + cod_letra [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + Tamanio [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] BY PEIA [C]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=cod_letra EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=Tamanio EMPTY=INCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=PEIA [1, 0, OTHERNM] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Indicador 2. Proporción de empresas que realizaron inversión ambiental en el año 2017 (%)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

**********************************************************************************************

* Indicador 3. Intensidad energética.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE EEYG = SUM.1(v9001, v9049) / 3.6. /* Energía eléctrica comprada + generada y consumida.

COMPUTE #F2 = 121.217. /* Coeficiente de paso de galones de GASOLINA SUPER a megajulios (MJ).
COMPUTE #F4 = 126.855. /* Coeficiente de paso de galones de GASOLINA EXTRA a megajulios (MJ).
COMPUTE #F6 = 131.232594. /* Coeficiente de paso de galones de JET FUEL a megajulios (MJ).
COMPUTE #F8 = 140.9315. /* Coeficiente de paso de galones de DIESEL a megajulios (MJ).
COMPUTE #F10 = 48.5. /* Coeficiente de paso de kilogramos de GAS LICUADO (GLP) a megajulios (MJ).
COMPUTE #F12 = 1055.05585. /* Coeficiente de paso de millones de BTU de GAS NATURAL a megajulios (MJ).
COMPUTE #F14 = 132.277367. /* Coeficiente de paso de galones de RESIDUO FUEL OIL a megajulios (MJ).
COMPUTE #F16 = 151.956. /* Coeficiente de paso de galones de CRUDO RESIDUAL a megajulios (MJ).
COMPUTE #F18 = 31.4. /* Coeficiente de paso de kilogramos de CARBON a megajulios (MJ).
COMPUTE #F20 = 151.22713. /* Coeficiente de paso de galones de SPRAY OIL a megajulios (MJ).
COMPUTE #F22 = 30.28328. /* Coeficiente de paso de galones de ABSORVER OIL a megajulios (MJ).
COMPUTE #F24 = 96.89808. /* Coeficiente de paso de galones de GASOLINA ECOPAIS a megajulios (MJ).
COMPUTE #F26 = 2.125. /* Coeficiente de paso de kilogramos de GRASAS a megajulios (MJ).
COMPUTE #F28 = 20.138381. /* Coeficiente de paso de galones de ACEITES a megajulios (MJ).

COMPUTE ECF = SUM.1(#F2 * v9052, #F4 * v9056, #F6 * v9060, #F8 * v9064, #F10 * v9068, #F12 * v9072, #F14 * v9076, #F16 * v9080, #F18 * v9084,
#F20 * v9088, #F22 * v9092, #F24 * v9096, #F26 * v9100, #F28 * v9104).

COMPUTE ENERGIA = SUM.1(EEYG, ECF).
COMPUTE VAB = valag.
EXECUTE.

DESCRIPTIVES VARIABLES=ENERGIA VAB
  /STATISTICS=SUM.

COMPUTE cod_letra_IE = (cod_letra <> 'D').
VARIABLE LABELS cod_letra_IE "Empresas NO pertenecientes al sector D. Suministro de electricidad, gas, vapor y aire acondicionado".
FREQUENCIES cod_letra_IE.

COMPUTE Filtro_IE = (VAB > 0 & ENERGIA > 0).
FREQUENCIES Filtro_IE.

* Tabulado a publicar.

WEIGHT BY f_exp.

FILTER BY Filtro_IE.

CTABLES
  /VLABELS VARIABLES=cod_letra Tamanio cod_letra_IE ENERGIA VAB NACIONAL DISPLAY=LABEL
  /TABLE cod_letra [C] + Tamanio [C] BY cod_letra_IE > (ENERGIA [S][SUM] + VAB [S][SUM] + NACIONAL [C][COUNT F40.0])
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=Tamanio ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=cod_letra_IE [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Indicador 3. Intensidad energética de las empresas (MJ / US$)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

DELETE VARIABLES cod_letra_IE.

**********************************************************************************************

* Indicador 4. Proporción de empresas que producen energías renovables.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE PEER = 0.
IF (MIN(v9007, v9015, v9023, v9031) = 1) PEER = 1.
VARIABLE LABELS PEER "Empresas que producen energías renovables 2017".
VALUE LABELS PEER 0'No' 1'Sí'.
FREQUENCIES PEER.

* Tabulado a publicar.

WEIGHT BY f_exp.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra Tamanio PEER DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + cod_letra [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + Tamanio [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] BY PEER [C]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=cod_letra EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Tamanio EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=PEER [1, 0, OTHERNM] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Indicador 4. Proporción de empresas que producen energías renovables en el año 2017 (%)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

**********************************************************************************************

* Indicador 5. Intensidad de generación de CO2.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

DELETE VARIABLES CO2 Filtro_CO2.

COMPUTE #F2 = 9.026438. /* Coeficiente de paso de galones de GASOLINA SUPER a kilogramos de CO2-eq.
COMPUTE #F4 = 8.865755. /* Coeficiente de paso de galones de GASOLINA EXTRA a kilogramos de CO2-eq.
COMPUTE #F6 = 8.538392. /* Coeficiente de paso de galones de JET FUEL a kilogramos de CO2-eq.
COMPUTE #F8 = 10.337088. /* Coeficiente de paso de galones de DIESEL a kilogramos de CO2-eq.
COMPUTE #F10 = 3. /* Coeficiente de paso de kilogramos de GAS LICUADO (GLP) a kilogramos de CO2-eq.
COMPUTE #F12 = 50.063507. /* Coeficiente de paso de millones de BTU de GAS NATURAL a kilogramos de CO2-eq.
COMPUTE #F14 = 9.763329. /* Coeficiente de paso de galones de RESIDUO FUEL OIL a kilogramos de CO2-eq.
COMPUTE #F16 = 9.90528. /* Coeficiente de paso de galones de CRUDO RESIDUAL a kilogramos de CO2-eq.
COMPUTE #F18 = 2.827. /* Coeficiente de paso de kilogramos de CARBON a kilogramos de CO2-eq.
COMPUTE #F20 = 0. /* Coeficiente de paso de galones de SPRAY OIL a kilogramos de CO2-eq.
COMPUTE #F22 = 0. /* Coeficiente de paso de galones de ABSORVER OIL a kilogramos de CO2-eq.
COMPUTE #F24 = 7.317974. /* Coeficiente de paso de galones de GASOLINA ECOPAIS a kilogramos de CO2-eq.
COMPUTE #F26 = 0.0465. /* Coeficiente de paso de kilogramos de GRASAS a kilogramos de CO2-eq.
COMPUTE #F28 = 0.6526. /* Coeficiente de paso de galones de ACEITES a kilogramos de CO2-eq.

COMPUTE CO2 = SUM.1(#F2 * v9052, #F4 * v9056, #F6 * v9060, #F8 * v9064, #F10 * v9068, #F12 * v9072, #F14 * v9076, #F16 * v9080, #F18 * v9084,
#F20 * v9088, #F22 * v9092, #F24 * v9096, #F26 * v9100, #F28 * v9104). /* La cantidad de CO2 equivalente sale en kilogramos.

DESCRIPTIVES VARIABLES=CO2
  /STATISTICS=SUM.

COMPUTE Filtro_CO2 = (CO2 > 0 & VAB > 0). /* Son las empresas que tienen combustibles consumidos positivos.
FREQUENCIES Filtro_CO2.

* Tabulado a publicar.

WEIGHT BY f_exp.

FILTER BY Filtro_CO2.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=cod_letra Tamanio CO2 VAB NACIONAL DISPLAY=LABEL
  /TABLE cod_letra [C] + Tamanio [C] BY CO2 [S][SUM] + VAB [S][SUM] + NACIONAL [C][COUNT F40.0]
  /CATEGORIES VARIABLES=cod_letra ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=BEFORE
  /CATEGORIES VARIABLES=Tamanio ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Indicador 5. Intensidad de generación de CO2 de las empresas (kg CO2-eq / US$)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

**********************************************************************************************

* Indicador 6. Intensidad de uso del agua.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

DO IF (v10006 = 1).
   COMPUTE v10007_S = v10007 / 264.17.
ELSE IF (v10006 = 2).
   COMPUTE v10007_S = v10007.
END IF.
EXECUTE.

COMPUTE H2O = SUM.1(v10000, v10007_S). /* La cantidad de agua total usada por las empresas en metros
/* cúbicos (no incluye aguas de fuentes naturales).

DESCRIPTIVES VARIABLES=H2O
  /STATISTICS=SUM.

COMPUTE cod_letra_H2O = (cod_letra <> 'E').
VARIABLE LABELS cod_letra_H2O "Empresas NO pertenecientes al sector E. Distribución de agua, alcantarillado, gestión de desechos y saneamiento".
FREQUENCIES cod_letra_H2O.

COMPUTE Filtro_H2O = (H2O > 0 & VAB > 0).
EXECUTE.

WEIGHT BY f_exp.

* Tabulado a publicar.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra Tamanio cod_letra_H2O Filtro_H2O H2O VAB DISPLAY=LABEL
  /TABLE NACIONAL [C] + cod_letra [C] + Tamanio [C] BY cod_letra_H2O > Filtro_H2O [C] > (H2O [S][SUM] + VAB [S][SUM, COUNT F40.0])
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=cod_letra_H2O [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Filtro_H2O [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=cod_letra Tamanio ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Indicador 6. Intensidad de uso de agua (m3 H2O / US$)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

DELETE VARIABLES cod_letra_H2O.

**********************************************************************************************

* Indicador 7. Proporción de aguas residuales que reciben tratamiento.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

COMPUTE AG_TRAT = v10ii6 * v10038 / 100.

DO IF (v10038 > 0).
    COMPUTE v10038_S = v10038.
END IF.

COMPUTE AG_TRAT_POS = (AG_TRAT > 0).
EXECUTE.

* Tabulado a publicar.

WEIGHT BY f_exp.

FILTER BY AG_TRAT_POS.

CTABLES
  /VLABELS VARIABLES=NACIONAL cod_letra Tamanio AG_TRAT v10038_S NACIONAL DISPLAY=LABEL
  /TABLE NACIONAL [C] + cod_letra [C] + Tamanio BY AG_TRAT [S][SUM] + v10038_S [S][SUM] + NACIONAL [C][COUNT F40.0]
  /CATEGORIES VARIABLES=NACIONAL EMPTY=EXCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=cod_letra EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Tamanio ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=NO
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
    TITLE='Indicador 7. Proporción de aguas residuales que reciben tratamiento (%)'
    CAPTION='INEC - Módulo de Información Ambiental Económica de la Encuesta Estructural Empresarial 2017'.

FILTER OFF.
USE ALL.
WEIGHT OFF.

****************************************************************************************************************************************************************************
*** FIN DE LA SINTAXIS DE TABULADOS E INDICADORES, MÓDULO AMBIENTAL DE LA ENCUESTA ESTRUCTURAL 2017.
*** Fecha última edición: 30 de septiembre de 2019.
****************************************************************************************************************************************************************************




